#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 assert-failure
version:              0.1.3.0
visibility:           public
id:                   assert-failure-0.1.3.0-8hIsIdxrMWu8NrmIWkKjeE
key:                  assert-failure-0.1.3.0-8hIsIdxrMWu8NrmIWkKjeE
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/assert-failure
synopsis:             Syntactic sugar improving '\''assert'\'' and '\''error'\''
description:
    This library contains syntactic sugar that makes it easier
    to write simple contracts with '\''assert'\'' and '\''error'\''
    and report the values that violate contracts.

category:             Control, Contract
abi:                  5be6f33d6914c596b47c2607917b849d
exposed:              True
exposed-modules:      Control.Exception.Assert.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/assert-failure-0.1.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/assert-failure-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/assert-failure-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-assert-failure
hs-libraries:         HSassert-failure-0.1.3.0-8hIsIdxrMWu8NrmIWkKjeE
depends:
    base-4.18.2.1 pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-assert-failure/html/assert-failure.haddock

haddock-html:         /usr/share/doc/haskell-assert-failure/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

